@@ -79,14 +79,15 @@ __END__
 
 =head1 NAME
 
-App::elsquid - Helper module
+App::elsquid - Helper module for the elsquid command
 
-=head1 SYNOPSIS
+
+=head1 DESCRIPTION
 
 Nothing in here is meant for public consumption.  Use L<elsquid>
 from the command line.
 
 
-=head1 DESCRIPTION
+=head1 AUTHOR
 
-This module exports the C<parse_line()> function for use in the main app.
+Axel Miesen <miesen@quadraginta-duo.de>
